<?php
/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'LFP_PLUGIN_VERSION', '1.4.0' );
define( 'LFP_ROOT', __DIR__ );
define( 'LFP_NAMESPACE', 'lfp-' );
define( 'LFP_SLUG', 'local-font-provider' );

define( 'LFP_MIN_PHP', '8.2' );
define( 'LFP_MIN_WP', '6.2.0' );

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.codevision.io/dsgvo-google-fonts/
 * @since             1.0.0
 * @package           Local_Font_Provider
 *
 * @wordpress-plugin
 * Plugin Name:       GDPR Compliant Google Fonts
 * Plugin URI:        https://www.codevision.io/dsgvo-google-fonts/
 * Description:       Replaces external google Font requests with a local hosted version to be GDPR compliant
 * Version:           1.4.0
 * Requires at least: 6.2.0
 * Tested up to:      6.6.1
 * Requires PHP:      8.2
 * Author:            codevision.io
 * Author URI:        https://www.codevision.io/
 * Text Domain:       local-font-provider
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
    die;
}

include_once __DIR__ . '/vendor/autoload.php';

function activate_local_font_provider() {

    Local_Font_Provider_Activator::activate();
}

function deactivate_local_font_provider() {

    Local_Font_Provider_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_local_font_provider' );


function lfp_get_license_manager() {

    $trial_link           = '"https://www.codevision.io/dsgvo-google-fonts/?utm_source=plugin-installation&utm_medium=license-notice&utm_campaign=trial-version-active"';
    $missing_license_link = '"https://www.codevision.io/dsgvo-google-fonts/?utm_source=plugin-installation&utm_medium=license-warning&utm_campaign=trial-version-expired"';
    $renew_license_link   = '"https://www.codevision.io/dsgvo-google-fonts/lizenz-verlangerung/?utm_source=plugin-installation&utm_medium=license-renewal&utm_campaign=payment-expired"';

    $parts                = [
        WP_CONTENT_DIR,
        \Local_Font_Provider::DOWNLOAD_FOLDER,
    ];
    $cache_folder         = implode( '/', $parts );
    $log_folder           = __DIR__ . '/log';
    $licenseServerUrl = 'https://license.codevision.io';

    $env = new \Codevision\Environment();

    $env->setPluginName( 'Local Font Provider' )
        ->setVersion( LFP_PLUGIN_VERSION )
        ->setBaseFile( __FILE__ )
        ->setBasePath( LFP_ROOT )
        ->setSlug( LFP_SLUG )
        ->setBaseUrl( plugin_dir_url( __FILE__ ) )
        ->setVendorUrl( plugin_dir_url( __FILE__ ) . 'vendor' );

    $manager = \Codevision\Licensing\Manager::getInstanceWithCompatiblityCheck( $env );

    $manager->setApiServer( $licenseServerUrl )
            ->setAuthKey( 'F680B653-516A-4532-9DB4-CAB38A5FC66F' )
            ->setNamespace( LFP_NAMESPACE )
            ->setLicenseInfoField( 'field_5bb74d6b0d467' )
            ->setLicenseKeyName( 'lfp_license' )
            ->setLicenseViewSlug( 'acf-options-lfp-license' )
            ->setMessages( [
                'headline'                     => 'Local Font Provider',
                'missing_license_admin_notice' => [
                    'Could not verify the License Key. Please buy a License Key <a href=%s>here</a>. As long as no valid License Key is found, the Plugin will not work correctly.',
                    $missing_license_link,
                ],
                'trial_period_admin_notice'    => [
                    'You are using Local Font Provider without a valid License Key. You have <strong>%%d</strong> days left for your trial. Please consider buying <a target="_blank" href=%s>here</a>.',
                    $trial_link,
                ],
                'trial'                        => [
                    'You are using Local Font Provider without a valid License Key. You have <strong>%%d</strong> days left for your trial. Please consider buying <a target="_blank" href=%s>here</a>.',
                    $trial_link,
                ],
                'trial_one_day_left'           => [
                    'You are using Local Font Provider without a valid License Key. You have only <strong>one</strong> day left for your trial. Please consider buying <a target="_blank" href=%s>here</a>.',
                    $trial_link,
                ],
                'license_renewal'           => [
                    'Your one year support for Local Font Provider has been expired on <strong>%%s</strong>. You do not receive any more updates. Please consider <a target="_blank" href=%s>renewing</a> your license to receive vital updates for your plugin.<br/><br/><a target="_blank" class="button button-secondary" href=%s>Renew Now!</a>',
                    $renew_license_link,
                    $renew_license_link,
                ],
            ] )
            ->getCompatibilityCheck()
            ->setSuccessFunction( function() use ( $manager ) {

                register_deactivation_hook( __FILE__, 'deactivate_local_font_provider' );

                $init = new Local_Font_Provider( $manager );
                $init->run();

            } )
            ->setTitle( 'Local Font Provider Compatibility Check' )
            ->setEscalationScore( 20 )
            ->add( new \Codevision\Compatibility\SimpleCheck( sprintf( 'License server secure connection test [ %s ] ', $licenseServerUrl ),
                sprintf( 'We cannot make a secure connection to our license server @ %s! Please check your web-firewall, security plugin(s) and hosting settings!', $licenseServerUrl ),
                function() use ( $licenseServerUrl ) {

                    $response = wp_remote_get( $licenseServerUrl );

                    return ! ( $response instanceof \WP_Error );
                }, 20 ) )
            ->add( new \Codevision\Compatibility\SimpleCheck( sprintf( 'PHP Version Check [ Required at least %s] ', LFP_MIN_PHP ),
                sprintf( 'Your PHP Version %s is too old, please upgrade to at least version %s to use this plugin!', PHP_VERSION, LFP_MIN_PHP ),
                function() {

                    return version_compare( PHP_VERSION, LFP_MIN_PHP, '>=' );
                },
                20 ) )
            ->add( new \Codevision\Compatibility\SimpleCheck( sprintf( 'Wordpress Version Check [ Required at least %s ]', LFP_MIN_WP ),
                sprintf( 'Your Wordpress version is too old for this plugin. At least, Wordpress version %s is required!', LFP_MIN_WP ),
                function() {

                    global $wp_version;

                    return version_compare( $wp_version, LFP_MIN_WP, '>=' );
                },
                20 ) )
            ->add( new \Codevision\Compatibility\SimpleCheck( sprintf( 'Testing Writing permissions to log folder [ %s ]', $log_folder ),
                sprintf( 'Could not write to log folder %s , logging will be disabled!', $log_folder ),
                function() use ( $log_folder ) {

                    if ( ! is_dir( $log_folder ) && ! @mkdir( $log_folder ) ) {
                        return false;
                    }

                    $test_file = $log_folder . '/.test';

                    if ( ! @touch( $test_file ) ) {
                        return false;
                    }

                    if ( ! @unlink( $test_file ) ) {
                        return false;
                    }

                    return true;
                },
                10 ) )
            ->add( new \Codevision\Compatibility\SimpleCheck( sprintf( 'Testing Writing permissions to font cache folder [ %s ]', $cache_folder ),
                sprintf( 'Could not write to cache folder, please create the folder \'%s\' with read, write and delete permissions!', $cache_folder ),
                function() use ( $cache_folder ) {

                    if ( ! is_dir( $cache_folder ) && ! @mkdir( $cache_folder ) ) {
                        return false;
                    }

                    $test_file = $cache_folder . '/.test';

                    if ( ! @touch( $test_file ) ) {
                        return false;
                    }

                    if ( ! @unlink( $test_file ) ) {
                        return false;
                    }

                    return true;
                },
                10 ) );

    return $manager;
}

function run_local_font_provider() {

    $manager = lfp_get_license_manager();
    $manager->init();

}

run_local_font_provider();


