<?php

class Lfp_ACF
{

    public function __construct()
    {

        add_action('plugins_loaded', [$this, 'handle_shipped_plugins']);

        include_once(ABSPATH.'wp-admin/includes/plugin.php');
    }

    public function init_bundle()
    {

        add_filter('acf/settings/path', fn($path) => $this->acf_settings_path($path));
        add_filter('acf/settings/dir', fn($dir) => $this->acf_settings_dir($dir));
        add_filter('acf/settings/url', fn($dir) => $this->acf_settings_dir($dir));

        add_filter('acf/settings/load_json', fn($paths) => $this->acf_json_load_point($paths));
        add_filter('acf/settings/save_json', fn($path) => $this->acf_json_save_point($path));

        if (get_option('lfp-acf-active') !== 'active') {
            update_option('lfp-acf-shipped-active', 'active');
            include_once(__DIR__.'/acf/acf.php');
        }


        return $this;
    }

    private function acf_settings_path($path)
    {

        // update path
        $path = __DIR__.'/acf/';

        // return
        return $path;

    }

    private function acf_settings_dir($dir)
    {

        $dir = plugin_dir_url(__FILE__).'acf/';

        // return
        return $dir;

    }

    private function acf_json_load_point($paths)
    {


        // append path
        $paths[] = __DIR__.'/acf/settings';

        // return
        return $paths;

    }

    private function acf_json_save_point($path)
    {

        // update path
        $path = __DIR__.'/acf/settings';


        // return
        return $path;

    }

    public function will_bundle_be_enabled()
    {

        $action = $_GET['action'] ?? false;

        if (!$action) {
            return $this;
        }

        if ($action !== 'activate') {
            return $this;
        }

        $plugin = $_GET['plugin'] ?? false;

        if (!$plugin) {
            return $this;
        }

        $bundles = $this->get_bundles();

        $selected_bundle = false;

        foreach ($bundles as $bundle => $name) {

            if (strpos($plugin, $bundle) === false) {
                continue;
            }

            $selected_bundle = $name;
            break;
        }

        if ($selected_bundle === false) {
            return $this;
        }

        update_option('lfp-acf-active', 'active');
        delete_option('lfp-acf-shipped-active');

        return $this;
    }

    private function get_bundles()
    {

        return [
            'advanced-custom-fields-pro/acf.php' => 'ACF',
        ];
    }

    public function handle_shipped_plugins()
    {

        $bundles = $this->get_bundles();

        foreach ($bundles as $bundle => $name) {

            if (is_plugin_active($bundle)) {
                update_option('lfp-acf-active', 'active');
            } else {
                delete_option('lfp-acf-active');
            }

        }

        return $this;
    }


}


$plugin = new Lfp_ACF();

$plugin->handle_shipped_plugins()
    ->will_bundle_be_enabled()
    ->init_bundle();
